@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.
 
-   $Id: add_file.c,v 1.93 2001/02/23 23:38:48 drscholl Exp $ */
+   $Id: add_file.c,v 1.94 2001/03/06 06:49:52 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
