@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: announce.c,v 1.22 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: announce.c,v 1.23 2001/03/06 06:49:52 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #ifndef WIN32
 #include <unistd.h>
