@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: config.c,v 1.90 2001/03/03 19:00:55 drscholl Exp $ */
+   $Id: config.c,v 1.97 2001/03/09 20:17:18 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -23,6 +27,7 @@ typedef enum
 VAR_TYPE;
 
 #define CF_ONCE	1		/* may only be set in config file or command line */
+#define CF_HIDDEN 2		/* can't be queried by a client */
 
 struct config
 {
@@ -30,35 +35,38 @@ struct config
     VAR_TYPE type;
     unsigned long val;
     unsigned long def;		/* default value */
-    u_int   flags;
+    unsigned int flags;
 };
 
 #define UL (unsigned long)
 
 static struct config Vars[] = {
 #ifndef ROUTING_ONLY
+    {"allow_share", VAR_TYPE_BOOL, ON_ALLOW_SHARE, 1, 0},
+    {"eject_when_full", VAR_TYPE_BOOL, ON_EJECT_WHEN_FULL, 0, 0},
+    {"eject_limit", VAR_TYPE_INT, UL & global.eject_limit, 0, 0},
     {"file_count_threshold", VAR_TYPE_INT, UL & File_Count_Threshold, 5000,
      0},
     {"max_results", VAR_TYPE_INT, UL & Max_Search_Results, 100, 0},
+    {"max_searches", VAR_TYPE_INT, UL & Max_Searches, 3, 0},
     {"max_shared", VAR_TYPE_INT, UL & Max_Shared, 5000, 0},
     {"stats_port", VAR_TYPE_INT, UL & Stats_Port, 8889, CF_ONCE},
-    {"max_searches", VAR_TYPE_INT, UL & Max_Searches, 3, 0},
     {"report_name", VAR_TYPE_STR, UL & global.report_name, 0, 0},
     {"report_ip", VAR_TYPE_STR, UL & global.report_ip, 0, 0},
     {"report_port", VAR_TYPE_INT, UL & global.report_port, 0, 0},
     {"stat_server_host", VAR_TYPE_STR, UL & global.stat_server,
      UL "stats.napigator.com", 0},
-    {"stat_server_pass", VAR_TYPE_STR, UL & global.stat_pass, UL "", 0},
+    {"stat_server_pass", VAR_TYPE_STR, UL & global.stat_pass, UL "",
+     CF_HIDDEN},
     {"stat_server_port", VAR_TYPE_INT, UL & global.stat_server_port, 8890, 0},
-    {"stat_server_user", VAR_TYPE_STR, UL & global.stat_user, UL "", 0},
+    {"stat_server_user", VAR_TYPE_STR, UL & global.stat_user, UL "",
+     CF_HIDDEN},
 #endif
-    {"allow_share", VAR_TYPE_BOOL, ON_ALLOW_SHARE, 1, 0},
     {"auto_link", VAR_TYPE_BOOL, ON_AUTO_LINK, 0, 0},
     {"auto_register", VAR_TYPE_BOOL, ON_AUTO_REGISTER, 0, 0},
     {"client_queue_length", VAR_TYPE_INT, UL & Client_Queue_Length, 102400,
      0},
     {"compression_level", VAR_TYPE_INT, UL & Compression_Level, 1, CF_ONCE},
-    {"eject_when_full", VAR_TYPE_BOOL, ON_EJECT_WHEN_FULL, 0, 0},
     {"flood_commands", VAR_TYPE_INT, UL & Flood_Commands, 0, 0},
     {"flood_time", VAR_TYPE_INT, UL & Flood_Time, 0, 0},
     {"ghost_kill", VAR_TYPE_BOOL, ON_GHOST_KILL, 1, 0},
@@ -87,7 +95,7 @@ static struct config Vars[] = {
     {"register_interval", VAR_TYPE_INT, UL & Register_Interval, 0, 0},
     {"registered_only", VAR_TYPE_BOOL, ON_REGISTERED_ONLY, 0, 0},
     {"remote_browse", VAR_TYPE_BOOL, ON_REMOTE_BROWSE, 1, 0},
-    {"restrict_registration", VAR_TYPE_BOOL, ON_RESTRICT_REGISTRATION, 0, 0},
+    {"remote_config", VAR_TYPE_BOOL, ON_REMOTE_CONFIG, 1, 0},
     {"search_timeout", VAR_TYPE_INT, UL & Search_Timeout, 180, 0},
     {"server_alias", VAR_TYPE_STR, UL & Server_Alias, 0, CF_ONCE},
     {"server_chunk", VAR_TYPE_INT, UL & Server_Chunk, 0, 0},
@@ -217,7 +225,7 @@ set_var (const char *var, const char *val, int init)
 	    return 0;
 	}
     }
-    log ("set_var(): unknown variable %s", var);
+    log ("set_var: unknown variable %s", var);
     return -1;
 }
 
@@ -239,29 +247,36 @@ int
 config (int init)
 {
     FILE   *f;
-    char   *ptr, *var, *val;
-    int     line = 0;
+    char   *ptr, *var;
+    int     len, line = 0;
     char    path[_POSIX_PATH_MAX];
+    char    buf[1024];
 
     snprintf (path, sizeof (path), "%s/config", Config_Dir);
 
     if ((f = fopen (path, "r")))
     {
 	log ("config: reading %s", path);
-	while (fgets (Buf, sizeof (Buf), f))
+	buf[sizeof buf - 1] = 0;
+	while (fgets (buf, sizeof (buf) - 1, f))
 	{
-	    line++;
-	    ptr = Buf;
-	    var = next_arg (&ptr);
-	    if (!var || *var == '#')
+	    ptr = buf;
+	    while (isspace (*ptr))
+		ptr++;
+	    if (!*ptr || *ptr == '#')
 		continue;
-	    val = next_arg (&ptr);
-	    if (!val)
+	    len = strlen (ptr);
+	    while (len > 0 && isspace (*(ptr + len - 1)))
+		len--;
+	    *(ptr + len) = 0;
+
+	    var = next_arg (&ptr);
+	    if (!ptr)
 	    {
-		log("config: error in %s:%d: missing value", path, line);
+		log ("config: error in %s:%d: missing value", path, line);
 		continue;
 	    }
-	    if (set_var (var, val, init) != 0)
+	    if (set_var (var, ptr, init) != 0)
 		log ("config: error in %s, line %d", path, line);
 	}
 	fclose (f);
@@ -322,6 +337,11 @@ HANDLER (server_config)
      */
     CHECK_USER_CLASS ("server_config");
 
+    if (!option (ON_REMOTE_CONFIG))
+    {
+	send_cmd (con, MSG_SERVER_NOSUCH, "remote configuration is disabled");
+	return;
+    }
     /* allow mods+ to query the config values, only elites can set them */
     if (con->user->level < LEVEL_MODERATOR)
     {
@@ -334,7 +354,10 @@ HANDLER (server_config)
     {
 	/* user requests all config variables */
 	for (ac = 0; ac < Vars_Size; ac++)
-	    query_var (con, &Vars[ac]);
+	{
+	    if (!(Vars[ac].flags & CF_HIDDEN))
+		query_var (con, &Vars[ac]);
+	}
     }
     else if (ac == 1)
     {
@@ -342,6 +365,8 @@ HANDLER (server_config)
 	for (ac = 0; ac < Vars_Size; ac++)
 	    if (!strcasecmp (av[0], Vars[ac].name))
 	    {
+		if (Vars[ac].flags & CF_HIDDEN)
+		    break;	/* hide this variable */
 		query_var (con, &Vars[ac]);
 		return;
 	    }
@@ -420,6 +445,12 @@ HANDLER (server_reconfig)
 	permission_denied (con);
 	return;
     }
+    if (!option (ON_REMOTE_CONFIG))
+    {
+	send_cmd (con, MSG_SERVER_NOSUCH, "remote configuration is disabled");
+	return;
+    }
+
     for (i = 0; i < Vars_Size; i++)
 	if (!strcmp (pkt, Vars[i].name))
 	{
@@ -477,6 +508,27 @@ nick_check (server_auth_t * auth, void *unused)
     }
 }
 
+void
+reload_config (void)
+{
+    log ("reload_config: reloading configuration files");
+    config (0);
+    /* since the motd is stored in memory, reread it */
+    motd_close ();
+    motd_init ();
+#ifndef ROUTING_ONLY
+    /* reread filter file */
+    load_filter ();
+    load_block ();
+#endif
+    load_server_auth ();
+
+    /* since the servers file may have changed, ensure that there is
+     * no nickname that matches an alias for a server.
+     */
+    list_foreach (Server_Auth, (list_callback_t) nick_check, 0);
+}
+
 /* 10116 [ :user ] [server]
  * reload configuration file
  */
@@ -495,23 +547,8 @@ HANDLER (rehash)
     notify_mods (SERVERLOG_MODE, "%s reloaded configuration on %s",
 		 sender->nick, pkt && *pkt ? pkt : Server_Name);
     if (!pkt || !*pkt || !strcasecmp (Server_Name, pkt))
-    {
-	config (0);
-	/* since the motd is stored in memory, reread it */
-	motd_close ();
-	motd_init ();
-#ifndef ROUTING_ONLY
-	/* reread filter file */
-	load_filter ();
-	load_block ();
-#endif
-	load_server_auth ();
+	reload_config ();
 
-	/* since the servers file may have changed, ensure that there is
-	 * no nickname that matches an alias for a server.
-	 */
-	list_foreach (Server_Auth, (list_callback_t) nick_check, 0);
-    }
     /* pass the message even if this is the server we are reloading so that
      * everyone sees the message
      */
