@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: download.c,v 1.56 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: download.c,v 1.57 2001/03/06 06:49:52 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <string.h>
 #include "opennap.h"
