@@ -2,7 +2,11 @@
    This is free software disributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: hash.c,v 1.15 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: hash.c,v 1.16 2001/03/06 06:49:52 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <string.h>
 #include <ctype.h>
