@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: init.c,v 1.62 2001/03/03 01:00:05 drscholl Exp $ */
+   $Id: init.c,v 1.66 2001/03/12 18:02:54 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #ifndef WIN32
 #include <grp.h>
@@ -11,9 +15,6 @@
 #include <sys/types.h>
 #include <netdb.h>
 #include <limits.h>
-#if HAVE_MLOCKALL
-#include <sys/mman.h>
-#endif /* HAVE_MLOCKALL */
 #endif /* !WIN32 */
 #include <signal.h>
 #include <time.h>
@@ -34,6 +35,9 @@
 #include "opennap.h"
 #include "hashlist.h"
 #include "debug.h"
+#if HAVE_MLOCKALL
+#include <sys/mman.h>
+#endif /* HAVE_MLOCKALL */
 
 static void
 lookup_hostname (void)
@@ -59,8 +63,10 @@ sighandler (int sig)
     log ("sighandler: caught signal %d", sig);
     switch (sig)
     {
-    case SIGINT:
     case SIGHUP:
+	reload_config ();
+	break;
+    case SIGINT:
     case SIGTERM:
 	SigCaught = 1;
 	break;
@@ -200,8 +206,6 @@ init_server (void)
 #endif /* PARANOID */
 #endif /* !WIN32 */
 
-    global.stat_server_fd = -1;
-
     log ("init_server: version %s starting", VERSION);
 
     Server_Start = time (&global.current_time);
@@ -336,6 +340,7 @@ init_server (void)
     /* set default values for napigator reporting if they were not
      * explicitly set in the config file
      */
+    global.stat_server_fd = -1;
     if (global.report_name == NULL)
 	global.report_name = STRDUP (Server_Name);
     if (global.report_ip == NULL)
