@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: join.c,v 1.85 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: join.c,v 1.87 2001/03/08 23:55:03 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #ifndef WIN32
 #include <unistd.h>
@@ -221,7 +225,7 @@ HANDLER (join)
 		return;
 	    }
 	    hash_add (Channels, chan->name, chan);
-	    log ("join: creating channel %s", chan->name);
+	    /* log ("join: creating channel %s", chan->name); */
 
 	    if (ISUSER (con))
 	    {
