@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: login.c,v 1.184 2001/03/03 19:00:55 drscholl Exp $ */
+   $Id: login.c,v 1.188 2001/03/09 20:29:47 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <stdio.h>
 #include <time.h>
@@ -97,6 +101,7 @@ zap_local_user (CONNECTION * con, const char *reason)
     destroy_connection (con);
 }
 
+#ifndef ROUTING_ONLY
 /* if the server is full, try to find the client connected to the server
  * the longest that isn't sharing any files.  expell that client to make
  * room for other (possibly sharing) clients.
@@ -104,7 +109,7 @@ zap_local_user (CONNECTION * con, const char *reason)
 static int
 eject_client (CONNECTION * con)
 {
-    int     i, loser = -1, leech = 0;
+    int     i, loser = -1, leech = 0, shared = 0x7fffffff;
     time_t  when = global.current_time;
 
     for (i = 0; i < global.clients_num; i++)
@@ -113,20 +118,33 @@ eject_client (CONNECTION * con)
 		!global.clients[i]->killed && /* skip already killed clients */
 	    (global.clients[i]->user->level == LEVEL_LEECH ||
 	     (global.clients[i]->user->level == LEVEL_USER &&
-	      global.clients[i]->user->sharing == 0)))
+	      global.clients[i]->user->sharing <= global.eject_limit)))
 	{
 	    /* if we already found a leech, don't boot a LEVEL_USER even
 	     * if the leech logged in more recently or is sharing files
 	     */
-	    if (leech && global.clients[i]->user->level > LEVEL_LEECH)
+	    if(leech && global.clients[i]->user->level > LEVEL_LEECH)
 		continue;
 
+	    /* always boot the client with the least files shared.  we skip
+	     * this check when we havent' yet found a leech, but the current
+	     * user is a leech, so that a leech sharing more files than a
+	     * regular user will get selected.
+	     */
+	    if (leech ||
+		    (!leech && global.clients[i]->user->level > LEVEL_LEECH))
+	    {
+		if (global.clients[i]->user->shared > shared)
+		    continue;
+	    }
+
 	    if (global.clients[i]->user->connected < when)
 	    {
 		loser = i;
 		when = global.clients[i]->user->connected;
 		if (global.clients[i]->user->level == LEVEL_LEECH)
 		    leech = 1;
+		shared = global.clients[i]->user->shared;
 	    }
 	}
     }
@@ -137,9 +155,10 @@ eject_client (CONNECTION * con)
      * here and not being routed.
      */
     kill_user_internal (NULL, global.clients[loser]->user, Server_Name, 0,
-			"server full, not sharing");
+			"server full, not sharing enough");
     return 1;			/* ok for current login to proceed despite being full */
 }
+#endif
 
 /* find the server name in the cache, or add it if it doesn't yet exist.
  * this allows one copy of the server name in memory rather than copying it
@@ -335,8 +354,10 @@ HANDLER (login)
 	    /* enforce maximum local users */
 	    if (global.clients_num >= Max_Connections)
 	    {
+#ifndef ROUTING_ONLY
 		/* check if another client can be ejected */
 		if (!option (ON_EJECT_WHEN_FULL) || !eject_client (con))
+#endif
 		{
 		    log ("login: max_connections (%d) reached",
 			 Max_Connections);
@@ -388,15 +409,15 @@ HANDLER (login)
 	/* TODO: generate a change port command */
     }
 
+    if (!db && option (ON_REGISTERED_ONLY))
+    {
+	send_cmd (con, MSG_SERVER_ERROR, "this is a restricted server");
+	destroy_connection (con);
+	return;
+    }
+
     if (tag == MSG_CLIENT_LOGIN && db == NULL)
     {
-	if (option (ON_REGISTERED_ONLY))
-	{
-	    send_cmd (con, MSG_SERVER_ERROR,
-		    "only registered accounts allowed on this server");
-	    destroy_connection (con);
-	    return;
-	}
 	/* the requested nick is not registered.  if we are supposed to
 	 * automatically register all new accounts, switch the command type
 	 * here to simulate MSG_CLIENT_LOGIN_REGISTER (6).
@@ -407,12 +428,6 @@ HANDLER (login)
 
     if (tag == MSG_CLIENT_LOGIN_REGISTER)
     {
-	if (option (ON_RESTRICT_REGISTRATION))
-	{
-	    send_cmd (con, MSG_SERVER_ERROR, "This is a restricted server");
-	    return;
-	}
-
 	/* check to see if the account is already registered */
 	if (db)
 	{
