@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: main.c,v 1.301 2001/03/03 01:00:05 drscholl Exp $ */
+   $Id: main.c,v 1.305 2001/03/09 08:37:48 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #if defined(WIN32) && !defined(__CYGWIN__)
 #include <windows.h>
@@ -425,18 +429,24 @@ accept_connection (int s)
     for (;;)
     {
 	sinsize = sizeof (sin);
+#if HAVE_ALARM
 	/* set an alarm just in case we end up blocking when a client
 	 * disconnects before we get to the accept()
 	 */
 	alarm (3);
+#endif
 	if ((f = accept (s, (struct sockaddr *) &sin, &sinsize)) < 0)
 	{
+#if HAVE_ALARM
 	    alarm (0);
+#endif
 	    if (N_ERRNO != EWOULDBLOCK)
 		nlogerr ("accept_connection", "accept");
 	    return;
 	}
+#if HAVE_ALARM
 	alarm (0);
+#endif
 
 	if (!acl_connection_allowed (BSWAP32 (sin.sin_addr.s_addr)))
 	{
@@ -495,7 +505,7 @@ static void
 usage (void)
 {
     fprintf (stderr,
-	     "usage: %s [ -bhsv ] [ -c DIR ] [ -p PORT ] [ -l IP ]\n",
+	     "usage: %s [ -bhrsv ] [ -c DIR ] [ -p PORT ] [ -l IP ]\n",
 	     PACKAGE);
     fprintf (stderr, "  -c DIR	read config files from DIR (default: %s)\n",
 	     SHAREDIR);
@@ -507,6 +517,7 @@ usage (void)
 	 stderr);
     fputs ("  -p PORT	listen on PORT for connections (default: 8888)\n",
 	   stderr);
+    fputs ("  -r		disable remote configuration commands\n", stderr);
     fputs
 	("  -s		channels may only be created by privileged users\n",
 	 stderr);
@@ -535,12 +546,13 @@ args (int argc, char **argv, int *sockfdcount)
     int    *sockfd;
     int     not_root = 1;
     int     port;
+    int	disable_remote = 0;
 
 #ifndef WIN32
     not_root = (getuid () != 0);
 #endif
 
-    while ((i = getopt (argc, argv, "bc:hl:p:svD")) != -1)
+    while ((i = getopt (argc, argv, "bc:hl:p:rsvD")) != -1)
     {
 	switch (i)
 	{
@@ -585,6 +597,9 @@ args (int argc, char **argv, int *sockfdcount)
 		exit (1);
 	    }
 	    break;
+	case 'r':
+	    disable_remote = 1;
+	    break;
 	case 's':
 	    Server_Flags |= ON_STRICT_CHANNELS;
 	    break;
@@ -631,6 +646,12 @@ args (int argc, char **argv, int *sockfdcount)
     if (init_server ())
 	exit (1);
 
+    /* if requested, disable remote configuration */
+    if (disable_remote)
+	    Server_Flags &= ~ON_REMOTE_CONFIG;
+    if (!(Server_Flags & ON_REMOTE_CONFIG))
+	    log("args: remote configuration disabled");
+
     /* if the interface was specified on the command line, override the
      * value from the config file
      */
@@ -1088,7 +1109,6 @@ main (int argc, char **argv)
 	    {
 		if (global.clients[i]->connecting)
 		    complete_connect (global.clients[i]);
-
 		else
 		{
 #if HAVE_POLL
@@ -1098,7 +1118,8 @@ main (int argc, char **argv)
 		    if (!ISSERVER (global.clients[i])
 			&& !global.clients[i]->sendbuf)
 		    {
-			log ("main: ERROR, fd %d (id %d) was writable with no pending data", global.clients[i]->fd, global.clients[i]->id);
+			log ("main: ERROR, fd %d (id %d) was writable with no pending data",
+				global.clients[i]->fd, global.clients[i]->id);
 			clear_write (global.clients[i]->fd);
 		    }
 #endif
@@ -1138,12 +1159,14 @@ main (int argc, char **argv)
 		clear_write (global.stat_server_fd);
 		/* nonblocking connect complete - check connection code */
 		if (getsockopt (global.stat_server_fd, SOL_SOCKET, SO_ERROR,
-			&code, &codesize))
+			SOCKOPTCAST &code, &codesize))
 		{
 		    logerr ("main","getsockopt");
 #if HAVE_POLL
 		    remove_fd (global.stat_server_fd);
 #endif
+		    CLOSE (global.stat_server_fd);
+		    global.stat_server_fd = -1;
 		}
 		else if (code)
 		{
@@ -1152,6 +1175,8 @@ main (int argc, char **argv)
 #if HAVE_POLL
 		    remove_fd (global.stat_server_fd);
 #endif
+		    CLOSE (global.stat_server_fd);
+		    global.stat_server_fd = -1;
 		}
 		else
 		    set_read (global.stat_server_fd);
