@@ -2,20 +2,23 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: metaserver.c,v 1.18 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: metaserver.c,v 1.20 2001/03/07 21:14:31 drscholl Exp $ */
 
 /* a simple napster metaserver.  redirects clients to a specific set of
    servers */
 
-#include <unistd.h>
-#include <signal.h>
+#include "config.h"
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
 #include <limits.h>
+#ifndef WIN32
+#include <signal.h>
+#include <unistd.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#endif
 #if HAVE_POLL
 #include <sys/poll.h>
 #endif /* HAVE_POLL */
