@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: network.c,v 1.42 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: network.c,v 1.44 2001/04/08 00:23:37 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <errno.h>
 #include <string.h>
@@ -257,7 +261,7 @@ set_limit (int attr, int value)
 	/* give feedback to the operator if the default value is lower than
 	   requested.  this is important when making the decision as to wheter
 	   or not the server needs to be run as uid 0 */
-	log ("set_limit(): warning: %d exceeds default hard limit of %d",
+	log ("set_limit: warning: %d exceeds default hard limit of %d",
 	     value, lim.rlim_max);
     }
     lim.rlim_cur = value;
@@ -267,7 +271,7 @@ set_limit (int attr, int value)
     if (attr == RLIMIT_FD_MAX && lim.rlim_cur > FD_SETSIZE)
     {
 	log
-	    ("set_limit(): warning: compiled limit (%d) is smaller than hard limit (%d)",
+	    ("set_limit: warning: compiled limit (%d) is smaller than hard limit (%d)",
 	     FD_SETSIZE, lim.rlim_max);
     }
 #endif /* HAVE_POLL */
