@@ -2,7 +2,7 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: opennap.h,v 1.293 2001/03/03 01:00:06 drscholl Exp $ */
+   $Id: opennap.h,v 1.300 2001/03/09 20:17:18 drscholl Exp $ */
 
 #ifndef opennap_h
 #define opennap_h
@@ -435,6 +435,7 @@ typedef struct
     int     stat_click;
     int     search_count;
 #ifndef ROUTING_ONLY
+    int     eject_limit;
     int     stat_server_fd;
     char   *stat_pass;
     char   *stat_server;
@@ -543,7 +544,7 @@ extern int Max_Rss_Size;
 #define ON_AUTO_LINK		(1<<10)	/* auto-link servers */
 #define ON_GHOST_KILL		(1<<11)	/* enable auto ghost kill */
 #define ON_ALLOW_SHARE		(1<<12)	/* allow file sharing */
-#define ON_RESTRICT_REGISTRATION	(1<<13)	/* don't allow auto nick reg. */
+#define ON_REMOTE_CONFIG	(1<<13)	/* is remote configuration allowed ? */
 
 extern char Buf[2048];
 
@@ -889,6 +890,7 @@ int     pop_user_server (CONNECTION * con, int tag, char **pkt, char **nick,
 			 USER ** user);
 void    print_args (int, char **);
 void    queue_data (CONNECTION *, char *, int);
+void	reload_config (void);
 void    remove_connection (CONNECTION *);
 void    remove_links (const char *);
 void    remove_user (CONNECTION *);
@@ -1100,14 +1102,15 @@ typedef unsigned int socklen_t;
 #define SOCKOPTCAST (char*)
 #define EINPROGRESS WSAEINPROGRESS
 #define EWOULDBLOCK WSAEWOULDBLOCK
+#define ENOBUFS WSAENOBUFS
 #define _POSIX_PATH_MAX 256
 /* winsock uses h_errno so we have to wrap the test for it here */
 #define N_ERRNO h_errno
 #define nlogerr(f,s) _logerr(f,s,h_errno)
 
-#define SHAREDIR "//c/opennap"
+#define SHAREDIR "C:\\opennap"
 #define PACKAGE "opennap"
-#define VERSION "0.40"
+#define VERSION "0.42"
 
 #define strcasecmp stricmp
 #define strncasecmp strnicmp
