@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: part_channel.c,v 1.20 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: part_channel.c,v 1.22 2001/03/08 23:55:03 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #ifndef WIN32
 #include <unistd.h>
@@ -81,7 +85,7 @@ part_channel (CHANNEL * chan, USER * user)
     /* if there are no users left in this channel, destroy it */
     else if ((chan->flags & ON_CHANNEL_REGISTERED) == 0)
     {
-	log ("part_channel: destroying channel %s", chan->name);
+/*	log ("part_channel: destroying channel %s", chan->name); */
 	hash_remove (Channels, chan->name);
     }
 }
