@@ -2,14 +2,17 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: search.c,v 1.127 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: search.c,v 1.130 2001/07/06 04:03:28 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 #include <stdio.h>
 #include <limits.h>
-#include <arpa/inet.h>
 #include "opennap.h"
 #include "debug.h"
 
@@ -1067,6 +1070,8 @@ HANDLER (remote_search_end)
     LIST  **list;
     char   *id = next_arg (&pkt);
 
+    CHECK_SERVER_CLASS ("remote_search_end");
+
     ASSERT (validate_connection (con));
     (void) con;
     (void) tag;
