@@ -2,14 +2,18 @@
    This is free software distributed under the terms of the
    GNU Public License.
 
-   $Id: server_connect.c,v 1.72 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: server_connect.c,v 1.75 2001/03/08 23:55:03 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
-#include <arpa/inet.h>
 #ifndef WIN32
 #include <unistd.h>
+#include <arpa/inet.h>
 #endif
 #include "opennap.h"
 #include "debug.h"
@@ -308,15 +312,14 @@ HANDLER (server_disconnect)
 /* force the server process to die */
 HANDLER (kill_server)
 {
-    USER   *user;
+    USER   *sender;
     int     ac = -1;
-    char   *av[2];
+    char   *av[2], *sender_name;
 
-    (void) tag;
     (void) len;
     ASSERT (validate_connection (con));
     ASSERT (pkt != 0);
-    if (pop_user (con, &pkt, &user) != 0)
+    if (pop_user_server (con, tag, &pkt, &sender_name, &sender) != 0)
 	return;
     if (pkt)
 	ac = split_line (av, FIELDS (av), pkt);
@@ -325,8 +328,8 @@ HANDLER (kill_server)
 	unparsable (con);
 	return;
     }
-    ASSERT (validate_user (user));
-    if (user->level < LEVEL_ELITE)
+    ASSERT (validate_user (sender));
+    if (sender->level < LEVEL_ELITE)
     {
 	permission_denied (con);
 	return;
@@ -334,8 +337,8 @@ HANDLER (kill_server)
 
     if (!is_linked (av[0]) && strcasecmp (Server_Name, av[0]) != 0)
     {
-	send_user (user, MSG_SERVER_NOSUCH,
-		   "kill server failed: no such server");
+	send_user (sender, MSG_SERVER_NOSUCH,
+		   "[%s] kill server failed: no such server", Server_Name);
 	return;
     }
 
@@ -343,15 +346,15 @@ HANDLER (kill_server)
 	truncate_reason (av[1]);
 
     pass_message_args (con, MSG_CLIENT_KILL_SERVER, ":%s %s \"%s\"",
-		       user->nick, av[0], (ac > 1) ? av[1] : "");
+		       sender_name, av[0], (ac > 1) ? av[1] : "");
 
-    notify_mods (SERVERLOG_MODE, "%s killed server %s: %s", user->nick,
+    notify_mods (SERVERLOG_MODE, "%s killed server %s: %s", sender_name,
 		 av[0], (ac > 1) ? av[1] : "");
 
     if (!strcasecmp (av[0], Server_Name))
     {
-	log ("kill_server(): shutdown by %s: %s", user->nick,
-	     (ac > 1) ? av[1] : "");
+	log ("kill_server: shutdown by %s: %s", sender_name,
+		(ac > 1) ? av[1] : "");
 	SigCaught = 1;		/* this causes the main event loop to exit */
     }
 }
