@@ -4,7 +4,11 @@
 
    Modified by drscholl@users.sourceforge.net 2/25/2000.
 
-   $Id: server_links.c,v 1.28 2001/01/08 10:15:15 drscholl Exp $ */
+   $Id: server_links.c,v 1.29 2001/03/06 06:49:53 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <string.h>
 #if !defined( WIN32) || defined(__CYGWIN__)
