@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.
 
-   $Id: server_login.c,v 1.57 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: server_login.c,v 1.58 2001/03/06 06:49:53 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <fcntl.h>
 #include <string.h>
