@@ -2,8 +2,13 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: setup.c,v 1.5 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: setup.c,v 1.7 2001/03/06 06:49:53 drscholl Exp $ */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "config.h"
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
