@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.
 
-   $Id: topic.c,v 1.28 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: topic.c,v 1.29 2001/03/06 06:49:53 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #ifndef WIN32
 #include <unistd.h>
