@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: userdb.c,v 1.31 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: userdb.c,v 1.33 2001/03/07 21:14:31 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <ctype.h>
 #include <stdio.h>
@@ -69,7 +73,7 @@ userdb_init (void)
 	return -1;
     }
     User_Db = hash_init (257, (hash_destroy) userdb_free);
-    log ("userdb_init(): reading %s", path);
+    log ("userdb_init: reading %s", path);
     if (fgets (Buf, sizeof (Buf), fp))
     {
 	if (strncmp (":version 1", Buf, 10))
@@ -85,7 +89,7 @@ userdb_init (void)
 	{
 	    if (invalid_nick (av[0]))
 	    {
-		log ("userdb_init(): %s: invalid nickname", av[0]);
+		log ("userdb_init: %s: invalid nickname", av[0]);
 		continue;
 	    }
 	    u = CALLOC (1, sizeof (USERDB));
@@ -115,7 +119,7 @@ userdb_init (void)
 	    level = get_level (av[3]);
 	    if (level < 0 || level > LEVEL_ELITE)
 	    {
-		log ("userdb_init(): invalid level %s for user %s", av[3],
+		log ("userdb_init: invalid level %s for user %s", av[3],
 		     u->nick);
 		level = LEVEL_USER;
 	    }
@@ -128,7 +132,7 @@ userdb_init (void)
 	}
 	else
 	{
-	    log ("userdb_init(): bad user db entry");
+	    log ("userdb_init: bad user db entry");
 	    print_args (ac, av);
 	}
     }
@@ -186,7 +190,7 @@ userdb_dump (void)
     FILE   *fp;
     char    path[_POSIX_PATH_MAX], tmppath[_POSIX_PATH_MAX];
 
-    log ("userdb_dump(): dumping user database");
+    log ("userdb_dump: dumping user database");
     snprintf (tmppath, sizeof (tmppath), "%s/users.tmp", Config_Dir);
     fp = fopen (tmppath, "w");
     if (!fp)
