@@ -2,26 +2,29 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: util.c,v 1.98 2001/02/15 08:39:45 drscholl Exp $
+   $Id: util.c,v 1.100 2001/03/07 21:14:31 drscholl Exp $
 
    This file contains various utility functions useful elsewhere in this
    server */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <fcntl.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
 #include <ctype.h>
+#include <stdlib.h>
 #ifndef WIN32
 #include <unistd.h>
 #include <sys/time.h>
-#endif
-#include <stdlib.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-
+#endif
 #include "md5.h"
 #include "opennap.h"
 #include "debug.h"
