@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
  
-   $Id: whois.c,v 1.59 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: whois.c,v 1.60 2001/03/06 06:49:53 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <stdio.h>
 #include <time.h>
